﻿namespace ResticLogParser.src
{
    internal class DirectoryNode : IComparable<DirectoryNode>
    {
        private List<DirectoryNode> _children = new();

        public DirectoryNode(DirectoryNode? parent, string name, string fullName)
        {
            Parent = parent;
            Name = name;
            FullName = fullName;
            AddedSize = 0;
            FileCount = 0;
        }

        public DirectoryNode? Parent { get; private set; }

        public string Name { get; private set; }

        public string FullName { get; private set; }

        public long AddedSize { get; set; }

        public int FileCount { get; set; }

        public DirectoryNode? FindChild(string name)
        {
            return _children.Find(x => x.Name == name);
        }

        public DirectoryNode AddChild(string name, string fullName)
        {
            var node = new DirectoryNode(this, name, fullName);
            _children.Add(node);
            return node;
        }

        public int CompareTo(DirectoryNode? other)
        {
            if (other == null)
            {
                return 1;
            }

            int compare = AddedSize.CompareTo(other.AddedSize);
            if (compare != 0)
            {
                return compare;
            }

            return FileCount.CompareTo(other.FileCount);
        }

        public override string ToString()
        {
            return $"Added {AddedSize} bytes, {FileCount} files, {FullName}";
        }
    }
}
